# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ config, ... }:

{
  services.django-apps.sites.gestiobds = {
    source = "https://git.dgnum.eu/DGNum/gestioCOF";
    branch = "bds-prod";
    domain = "gestion.bds.ens.fr";

    nginx = {
      enableACME = true;
      forceSSL = true;
    };

    webHookSecret = config.age.secrets."webhook-gestiobds_token".path;

    overlays.nix-pkgs = [
      # Required packages
      "authens"
      "django-bootstrap-form"
      "django-cas-ng"
      "loadcredential"

      # Dependencies
      "python-cas"
    ];

    dependencies = ps: [
      ps.authens
      ps.django
      ps.django-bootstrap-form
      ps.django-autocomplete-light
      ps.django-cas-ng
      ps.django-widget-tweaks
      ps.loadcredential
      ps.pillow
    ];

    application = {
      module = "gestioasso";
      settingsModule = "gestioasso.settings_bds";
    };

    credentials = {
      SECRET_KEY = config.age.secrets."dj_gestiobds-secret_key_file".path;
      SYMPA_PASSWORD = config.age.secrets."dj_gestiobds-sympa_password_file".path;
      SYMPA_USERNAME = config.age.secrets."dj_gestiobds-sympa_username_file".path;
    };
  };
}
