# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
# SPDX-FileContributor: Julien Malka <julien.malka@dgnum.eu>
# SPDX-FileContributor: Maurice Debray <maurice.debray@dgnum.eu>
# SPDX-FileContributor: Ryan Lahfa <ryan.lahfa@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

###
# File specifying all the deployement options for the nodes administrated by the dgnum.
#
# Node metadata template is:
#
# NODE_NAME = {
#   adminGroups = []; # List of groups that have root access
#   admins = []; # List of individuals that have root access
#   deployment = {}; # Colmena deployment options
#   nixpkgs = "unstable" or "22.11"; # nixpkgs version
# }

/*
  Liste des différents sites :
  - rat01 -> VM du NPSPI
  - pav01 -> Salle serveur sous le pavillon Pasteur
  - oik01 -> Local DGNum Jourdan
  - hyp01 -> Salle serveur Hypnos 1
  - luj01 -> VM de Luj
*/
{
  nodes = {
    bridge01 = {
      site = "hyp01";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIP5bS3iBXz8wycBnTvI5Qi79WLu0h4IVv/EOdKYbP5y7" ];

      hashedPassword = "$y$j9T$EPJdz70kselouXAVUmAH01$8nYbUBY9NPTMfYigegY0qFSdxJwhqzW8sFacDqEYCP5";

      stateVersion = "24.05";

      adminGroups = [ "fai" ];

      deployment = {
        targetHost = "fd26:baf9:d250:8000::ffff";
        sshOptions = [
          "-J"
          "root@vault01.hyp01.infra.dgnum.eu"
        ];
      };

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };
    };

    build01 = {
      site = "pot01";

      hashedPassword = "$y$j9T$n83qOn1OkQhFwQe50tPM11$jZ1tvgqMTcp4HLGEfJmTMsf0NnRUYQkzco9vibWTpU2";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIIYJcEMQpOyKInqtd2/brnSQuzwgv6fNPlTSQx9tcvPu" ];

      stateVersion = "24.11";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      admins = [ "ecoppens" ];

      deployment = {
        targetHost = "build01.dgnum";
      };
    };

    cof02 = {
      site = "pav01";

      hashedPassword = "$y$j9T$7NuClEAftCG0O7AA0KLK10$/ZLXV73tiZVMXFdgKfa4yVeYk.Qdea6uIgQTrtWHIbA";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIAfYSj2V0jmricxbH/ZumcLXZuMqj5/AS9BvRoU1zejg" ];

      stateVersion = "24.11";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      admins = [ "catvayor" ];

      deployment = {
        targetHost = "129.199.146.54";
      };
    };

    compute01 = {
      site = "pav01";
      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIE/YluSVS+4h3oV8CIUj0OmquyJXju8aEQy0Jz210vTu" ];

      hashedPassword = "$y$j9T$2nxZHq84G7fWvWMEaGavE/$0ADnmD9qMpXJJ.rWWH9086EakvZ3wAg0mSxZYugOf3C";

      stateVersion = "23.05";
      nix-modules = [ "services/stirling-pdf" ];

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };
    };

    geo01 = {
      site = "oik01";
      deployment.tags = [ "geo" ];

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIEl6Pubbau+usQkemymoSKrTBbrX8JU5m5qpZbhNx8p4" ];

      hashedPassword = "$y$j9T$2XmDpJu.QLhV57yYCh5Lf1$LK.X0HKB02Q0Ujvhj5nIofW2IRrIAL/Uxnvl9AXM1L8";

      deployment.targetHost = "geo01.dgnum";

      stateVersion = "24.05";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };
    };

    geo02 = {
      site = "oik01";
      deployment.tags = [ "geo" ];

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFNXaCS0/Nsu5npqQk1TP6wMHCVIOaj4pblp2tIg6Ket" ];

      hashedPassword = "$y$j9T$Q4fbMpSm9beWu4DPNAR9t0$dx/1pH4GPY72LpS5ZiECXAZFDdxwmIywztsX.qo2VVA";

      deployment.targetHost = "geo02.dgnum";

      stateVersion = "24.05";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };
    };

    hypervisor01 = {
      site = "pot01";

      hashedPassword = "$y$j9T$Yw.M.epJj/sakb4Gq/9WV0$P85aQPo/FmFM1.ap413UL3vlGk3mavHwmaALKKDd4n.";

      stateVersion = "24.11";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAINPE0typcnvSioMfdLUloIfR5zcf/X0k6201xMHoQBCr" ];

      adminGroups = [ "hypervisors" ];

      deployment = {
        targetHost = "hypervisor01.dgnum";
      };
    };

    hypervisor02 = {
      site = "pot01";

      hashedPassword = "$y$j9T$Zu98DVlKq7KP5GmIHOwBy1$Bd7W6LstWDm8zjbZ9JSPLnhMFPmZgmU4e7t7u6EhavA";

      stateVersion = "24.11";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIPETkWlOfESXQic+HgfGLV/T4Nqg0WjdDbEqtgDwkH+S" ];

      adminGroups = [ "hypervisors" ];

      deployment = {
        targetHost = "hypervisor02.dgnum";
      };
    };

    hypervisor03 = {
      site = "pot01";

      hashedPassword = "$y$j9T$plTv9.UwmkTODagd4docj0$3zd35wPSsamygiYngwfDGICapKbx5UbzyLBhAwOUSfC";

      stateVersion = "24.11";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFLF0mxSGitsDE3/YXfrHNjtOMUt4HT2MbryyUKPLSBI" ];

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      adminGroups = [ "hypervisors" ];

      deployment = {
        targetHost = "hypervisor03.dgnum";
      };
    };

    rescue01 = {
      site = "luj01";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIEJa02Annu8o7ggPjTH/9ttotdNGyghlWfU9E8pnuLUf" ];

      deployment.targetHost = "v6.rescue01.luj01.infra.dgnum.eu";

      hashedPassword = "$y$j9T$nqoMMu/axrD0m8AlUFdbs.$UFVmIdPAOHBe2jJv5HJJTcDgINC7LTnSGRQNs9zS1mC";

      stateVersion = "23.11";
      vm-cluster = "Hyperviseur Luj";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      nix-modules = [
        "services/netbird/server.nix"
      ];
    };

    storage01 = {
      site = "pav01";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIA0s+rPcEcfWCqZ4B2oJiWT/60awOI8ijL1rtDM2glXZ" ];

      hashedPassword = "$y$j9T$tvRu1EJ9MwDSvEm0ogwe70$bKSw6nNteN0L3NOy2Yix7KlIvO/oROQmQ.Ynq002Fg8";

      stateVersion = "23.11";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      nix-modules = [
        "services/forgejo-nix-runners"
        "services/netbird/server.nix"
      ];
    };

    tower01 = {
      site = "oik01";

      hashedPassword = "$y$j9T$axihKDa.CrYcyoamJWxBq1$bl4TfropTrwLqMy6XK0DKkWRyx9b74kyI/ukE8X5iiD";

      sshKeys = [
        "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAICVpR+TMRLGAfhn7Q0C3tKOydYYjfoC/e1ZYbKpby01Z"
      ];

      stateVersion = "24.11";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      admins = [ "ecoppens" ];
    };

    vault01 = {
      site = "hyp01";
      deployment.targetHost = "vault01.hyp01.infra.dgnum.eu";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIAJA6VA7LENvTRlKdcrqt8DxDOPvX3bg3Gjy9mNkdFEW" ];

      hashedPassword = "$y$j9T$5osXVNxCDxu3jIndcyh7G.$UrjiDRpMu3W59tKHLGNdLWllZh.4p8IM4sBS5SrNrN1";

      stateVersion = "23.11";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      adminGroups = [ "fai" ];
    };

    web01 = {
      site = "rat01";

      deployment.tags = [ "web" ];

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIPR+lewuJ/zhCyizJGJOH1UaAB699ItNKEaeuoK57LY5" ];

      hashedPassword = "$y$j9T$9YqXO93VJE/GP3z8Sh4h51$hrBsEPL2O1eP/wBZTrNT8XV906V4JKbQ0g04IWBcyd2";

      stateVersion = "23.05";
      vm-cluster = "Hyperviseur NPS";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };
    };

    web02 = {
      site = "rat01";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAID+QDE+GgZs6zONHvzRW15BzGJNW69k2BFZgB/Zh/tLX" ];

      hashedPassword = "$y$j9T$p42UVNy78PykkQOjPwXNJ/$B/zCUOrHXVSFGUY63wnViMiSmU2vCWsiX0y62qqgNQ5";

      stateVersion = "24.05";
      vm-cluster = "Hyperviseur NPS";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };
    };

    web03 = {
      site = "rat01";

      sshKeys = [ "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAICrWsMEfK86iaO9SubMqE2UvZNtHkLY5VUod/bbqKC0L" ];

      hashedPassword = "$y$j9T$Un/tcX5SPKNXG.sy/BcTa.$kyNHELjb1GAOWnauJfcjyVi5tacWcuEBKflZDCUC6x4";

      stateVersion = "24.05";
      vm-cluster = "Hyperviseur NPS";

      nixpkgs = {
        version = "24.11";
        system = "nixos";
      };

      admins = [ "catvayor" ];
    };
  };
}
